==> transformer_lens-1.0.0.tar.gz: transformer_lens-1.0.0/transformer_lens/model_properties_table.md <==
|                                |   d_model |   d_mlp |   d_head |   d_vocab | act_fn    |   n_heads |   n_layers |   n_ctx | n_params   |
|:-------------------------------|----------:|--------:|---------:|----------:|:----------|----------:|-----------:|--------:|:-----------|
| gpt2-small                     |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| gpt2-medium                    |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| gpt2-large                     |      1280 |    5120 |       64 |     50257 | gelu      |        20 |         36 |    1024 | 708M       |
| gpt2-xl                        |      1600 |    6400 |       64 |     50257 | gelu      |        25 |         48 |    1024 | 1.5B       |
| distillgpt2                    |       768 |    3072 |       64 |     50257 | gelu      |        12 |          6 |    1024 | 42M        |
| opt-125m                       |       768 |    3072 |       64 |     50272 | relu      |        12 |         12 |    2048 | 85M        |
| opt-1.3b                       |      2048 |    8192 |       64 |     50272 | relu      |        32 |         24 |    2048 | 1.2B       |
| opt-2.7b                       |      2560 |   10240 |       80 |     50272 | relu      |        32 |         32 |    2048 | 2.5B       |
| opt-6.7b                       |      4096 |   16384 |      128 |     50272 | relu      |        32 |         32 |    2048 | 6.4B       |
| opt-13b                        |      5120 |   20480 |      128 |     50272 | relu      |        40 |         40 |    2048 | 13B        |
| opt-30b                        |      7168 |   28672 |      128 |     50272 | relu      |        56 |         48 |    2048 | 30B        |
| opt-66b                        |      9216 |   36864 |      128 |     50272 | relu      |        72 |         64 |    2048 | 65B        |
| gpt-neo-125M                   |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    2048 | 85M        |
| gpt-neo-1.3B                   |      2048 |    8192 |      128 |     50257 | gelu      |        16 |         24 |    2048 | 1.2B       |
| gpt-neo-2.7B                   |      2560 |   10240 |      128 |     50257 | gelu      |        20 |         32 |    2048 | 2.5B       |
| gpt-j-6B                       |      4096 |   16384 |      256 |     50400 | gelu      |        16 |         28 |    2048 | 5.6B       |
| gpt-neox-20b                   |      6144 |   24576 |       96 |     50432 | gelu_fast |        64 |         44 |    2048 | 20B        |
| stanford-gpt2-small-a          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-small-b          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-small-c          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-small-d          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-small-e          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-medium-a         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| stanford-gpt2-medium-b         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| stanford-gpt2-medium-c         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| stanford-gpt2-medium-d         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| stanford-gpt2-medium-e         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| pythia-19m                     |       512 |    2048 |       64 |     50304 | gelu      |         8 |          6 |    2048 | 19M        |
| pythia-125m                    |       768 |    3072 |       64 |     50304 | gelu      |        12 |         12 |    2048 | 85M        |
| pythia-350m                    |      1024 |    4096 |       64 |     50304 | gelu      |        16 |         24 |    2048 | 302M       |
| pythia-800m                    |      2048 |    8192 |      256 |     50304 | gelu      |         8 |         16 |    2048 | 805M       |
| pythia-1.3b                    |      2048 |    8192 |      128 |     50304 | gelu      |        16 |         24 |    2048 | 1.2B       |
| pythia-6.7b                    |      4096 |   16384 |      128 |     50432 | gelu      |        32 |         32 |    2048 | 6.4B       |
| pythia-13b                     |      5120 |   20480 |      128 |     50688 | gelu      |        40 |         36 |    2048 | 11B        |
| pythia-19m-deduped             |       512 |    2048 |       64 |     50304 | gelu      |         8 |          6 |    2048 | 19M        |
| pythia-125m-deduped            |       768 |    3072 |       64 |     50304 | gelu      |        12 |         12 |    2048 | 85M        |
| EleutherAI/pythia-350m-deduped |      1024 |    4096 |       64 |     50304 | gelu      |        16 |         24 |    2048 | 302M       |
| pythia-1.3b-deduped            |      2048 |    8192 |      128 |     50304 | gelu      |        16 |         24 |    2048 | 1.2B       |
| pythia-6.7b-deduped            |      4096 |   16384 |      128 |     50432 | gelu      |        32 |         32 |    2048 | 6.4B       |
| pythia-13b-deduped             |      5120 |   20480 |      128 |     50688 | gelu      |        40 |         36 |    2048 | 11B        |
| solu-1l-old                    |      1024 |    4096 |       64 |     50278 | solu      |        16 |          1 |    1024 | 13M        |
| solu-2l-old                    |       736 |    2944 |       64 |     50278 | solu      |        11 |          2 |    1024 | 13M        |
| solu-4l-old                    |       512 |    2048 |       64 |     50278 | solu      |         8 |          4 |    1024 | 13M        |
| solu-6l-old                    |       768 |    3072 |       64 |     50278 | solu      |        12 |          6 |    1024 | 42M        |
| solu-8l-old                    |      1024 |    4096 |       64 |     50278 | solu      |        16 |          8 |    1024 | 101M       |
| solu-10l-old                   |      1280 |    5120 |       64 |     50278 | solu      |        20 |         10 |    1024 | 197M       |
| solu-12l-old                   |      1536 |    6144 |       64 |     50278 | solu      |        24 |         12 |    1024 | 340M       |
| solu-1l                        |       512 |    2048 |       64 |     48262 | solu      |         8 |          1 |    1024 | 3.1M       |
| solu-2l                        |       512 |    2048 |       64 |     48262 | solu      |         8 |          2 |    1024 | 6.3M       |
| solu-3l                        |       512 |    2048 |       64 |     48262 | solu      |         8 |          3 |    1024 | 9.4M       |
| solu-4l                        |       512 |    2048 |       64 |     48262 | solu      |         8 |          4 |    1024 | 13M        |
| solu-6l                        |       768 |    3072 |       64 |     48262 | solu      |        12 |          6 |    1024 | 42M        |
| solu-8l                        |      1024 |    4096 |       64 |     48262 | solu      |        16 |          8 |    1024 | 101M       |
| solu-10l                       |      1280 |    5120 |       64 |     48262 | solu      |        20 |         10 |    1024 | 197M       |
| solu-12l                       |      1536 |    6144 |       64 |     48262 | solu      |        24 |         12 |    1024 | 340M       |
| gelu-1l                        |       512 |    2048 |       64 |     48262 | gelu      |         8 |          1 |    1024 | 3.1M       |
| gelu-2l                        |       512 |    2048 |       64 |     48262 | gelu      |         8 |          2 |    1024 | 6.3M       |
| gelu-3l                        |       512 |    2048 |       64 |     48262 | gelu      |         8 |          3 |    1024 | 9.4M       |
| gelu-4l                        |       512 |    2048 |       64 |     48262 | gelu      |         8 |          4 |    1024 | 13M        |
| attn-only-1l                   |       512 |    2048 |       64 |     48262 | attn_only |         8 |          1 |    1024 | 1.0M       |
| attn-only-2l                   |       512 |    2048 |       64 |     48262 | attn_only |         8 |          2 |    1024 | 2.1M       |
| attn-only-3l                   |       512 |    2048 |       64 |     48262 | attn_only |         8 |          3 |    1024 | 3.1M       |
| attn-only-4l                   |       512 |    2048 |       64 |     48262 | attn_only |         8 |          4 |    1024 | 4.2M       |
| attn-only-2l-demo              |       512 |    2048 |       64 |     50277 | attn_only |         8 |          2 |    1024 | 2.1M       |

==> transformer_lens-1.1.1.tar.gz: transformer_lens-1.1.1/transformer_lens/model_properties_table.md <==
|                                |   d_model |   d_mlp |   d_head |   d_vocab | act_fn    |   n_heads |   n_layers |   n_ctx | n_params   |
|:-------------------------------|----------:|--------:|---------:|----------:|:----------|----------:|-----------:|--------:|:-----------|
| gpt2-small                     |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| gpt2-medium                    |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| gpt2-large                     |      1280 |    5120 |       64 |     50257 | gelu      |        20 |         36 |    1024 | 708M       |
| gpt2-xl                        |      1600 |    6400 |       64 |     50257 | gelu      |        25 |         48 |    1024 | 1.5B       |
| distillgpt2                    |       768 |    3072 |       64 |     50257 | gelu      |        12 |          6 |    1024 | 42M        |
| opt-125m                       |       768 |    3072 |       64 |     50272 | relu      |        12 |         12 |    2048 | 85M        |
| opt-1.3b                       |      2048 |    8192 |       64 |     50272 | relu      |        32 |         24 |    2048 | 1.2B       |
| opt-2.7b                       |      2560 |   10240 |       80 |     50272 | relu      |        32 |         32 |    2048 | 2.5B       |
| opt-6.7b                       |      4096 |   16384 |      128 |     50272 | relu      |        32 |         32 |    2048 | 6.4B       |
| opt-13b                        |      5120 |   20480 |      128 |     50272 | relu      |        40 |         40 |    2048 | 13B        |
| opt-30b                        |      7168 |   28672 |      128 |     50272 | relu      |        56 |         48 |    2048 | 30B        |
| opt-66b                        |      9216 |   36864 |      128 |     50272 | relu      |        72 |         64 |    2048 | 65B        |
| gpt-neo-125M                   |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    2048 | 85M        |
| gpt-neo-1.3B                   |      2048 |    8192 |      128 |     50257 | gelu      |        16 |         24 |    2048 | 1.2B       |
| gpt-neo-2.7B                   |      2560 |   10240 |      128 |     50257 | gelu      |        20 |         32 |    2048 | 2.5B       |
| gpt-j-6B                       |      4096 |   16384 |      256 |     50400 | gelu      |        16 |         28 |    2048 | 5.6B       |
| gpt-neox-20b                   |      6144 |   24576 |       96 |     50432 | gelu_fast |        64 |         44 |    2048 | 20B        |
| stanford-gpt2-small-a          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-small-b          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-small-c          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-small-d          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-small-e          |       768 |    3072 |       64 |     50257 | gelu      |        12 |         12 |    1024 | 85M        |
| stanford-gpt2-medium-a         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| stanford-gpt2-medium-b         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| stanford-gpt2-medium-c         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| stanford-gpt2-medium-d         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| stanford-gpt2-medium-e         |      1024 |    4096 |       64 |     50257 | gelu      |        16 |         24 |    1024 | 302M       |
| pythia-70m                     |       512 |    2048 |       64 |     50304 | gelu      |         8 |          6 |    2048 | 19M        |
| pythia-160m                    |       768 |    3072 |       64 |     50304 | gelu      |        12 |         12 |    2048 | 85M        |
| pythia-410m                    |      1024 |    4096 |       64 |     50304 | gelu      |        16 |         24 |    2048 | 302M       |
| pythia-1b                    |      2048 |    8192 |      256 |     50304 | gelu      |         8 |         16 |    2048 | 805M       |
| pythia-1.4b                    |      2048 |    8192 |      128 |     50304 | gelu      |        16 |         24 |    2048 | 1.2B       |
| pythia-6.9b                    |      4096 |   16384 |      128 |     50432 | gelu      |        32 |         32 |    2048 | 6.4B       |
| pythia-12b                     |      5120 |   20480 |      128 |     50688 | gelu      |        40 |         36 |    2048 | 11B        |
| pythia-70m-deduped             |       512 |    2048 |       64 |     50304 | gelu      |         8 |          6 |    2048 | 19M        |
| pythia-160m-deduped            |       768 |    3072 |       64 |     50304 | gelu      |        12 |         12 |    2048 | 85M        |
| EleutherAI/pythia-410m-deduped |      1024 |    4096 |       64 |     50304 | gelu      |        16 |         24 |    2048 | 302M       |
| pythia-1.4b-deduped            |      2048 |    8192 |      128 |     50304 | gelu      |        16 |         24 |    2048 | 1.2B       |
| pythia-6.9b-deduped            |      4096 |   16384 |      128 |     50432 | gelu      |        32 |         32 |    2048 | 6.4B       |
| pythia-12b-deduped             |      5120 |   20480 |      128 |     50688 | gelu      |        40 |         36 |    2048 | 11B        |
| solu-1l-old                    |      1024 |    4096 |       64 |     50278 | solu      |        16 |          1 |    1024 | 13M        |
| solu-2l-old                    |       736 |    2944 |       64 |     50278 | solu      |        11 |          2 |    1024 | 13M        |
| solu-4l-old                    |       512 |    2048 |       64 |     50278 | solu      |         8 |          4 |    1024 | 13M        |
| solu-6l-old                    |       768 |    3072 |       64 |     50278 | solu      |        12 |          6 |    1024 | 42M        |
| solu-8l-old                    |      1024 |    4096 |       64 |     50278 | solu      |        16 |          8 |    1024 | 101M       |
| solu-10l-old                   |      1280 |    5120 |       64 |     50278 | solu      |        20 |         10 |    1024 | 197M       |
| solu-12l-old                   |      1536 |    6144 |       64 |     50278 | solu      |        24 |         12 |    1024 | 340M       |
| solu-1l                        |       512 |    2048 |       64 |     48262 | solu      |         8 |          1 |    1024 | 3.1M       |
| solu-2l                        |       512 |    2048 |       64 |     48262 | solu      |         8 |          2 |    1024 | 6.3M       |
| solu-3l                        |       512 |    2048 |       64 |     48262 | solu      |         8 |          3 |    1024 | 9.4M       |
| solu-4l                        |       512 |    2048 |       64 |     48262 | solu      |         8 |          4 |    1024 | 13M        |
| solu-6l                        |       768 |    3072 |       64 |     48262 | solu      |        12 |          6 |    1024 | 42M        |
| solu-8l                        |      1024 |    4096 |       64 |     48262 | solu      |        16 |          8 |    1024 | 101M       |
| solu-10l                       |      1280 |    5120 |       64 |     48262 | solu      |        20 |         10 |    1024 | 197M       |
| solu-12l                       |      1536 |    6144 |       64 |     48262 | solu      |        24 |         12 |    1024 | 340M       |
| gelu-1l                        |       512 |    2048 |       64 |     48262 | gelu      |         8 |          1 |    1024 | 3.1M       |
| gelu-2l                        |       512 |    2048 |       64 |     48262 | gelu      |         8 |          2 |    1024 | 6.3M       |
| gelu-3l                        |       512 |    2048 |       64 |     48262 | gelu      |         8 |          3 |    1024 | 9.4M       |
| gelu-4l                        |       512 |    2048 |       64 |     48262 | gelu      |         8 |          4 |    1024 | 13M        |
| attn-only-1l                   |       512 |    2048 |       64 |     48262 | attn_only |         8 |          1 |    1024 | 1.0M       |
| attn-only-2l                   |       512 |    2048 |       64 |     48262 | attn_only |         8 |          2 |    1024 | 2.1M       |
| attn-only-3l                   |       512 |    2048 |       64 |     48262 | attn_only |         8 |          3 |    1024 | 3.1M       |
| attn-only-4l                   |       512 |    2048 |       64 |     48262 | attn_only |         8 |          4 |    1024 | 4.2M       |
| attn-only-2l-demo              |       512 |    2048 |       64 |     50277 | attn_only |         8 |          2 |    1024 | 2.1M       |
